/* This file is part of Cloudy and is copyright (C) 1978-2007 by Gary J. Ferland.
 * For conditions of distribution and use, see copyright notice in license.txt */
/* runs pure collisional models at range of temperatures, prints cooling */
#include "cddefines.h"
#include "cddrive.h"

/*int main( int argc, char *argv[] )*/
int main( void )
{
	int lgBAD ;
	double telog , cooling, hden , tehigh , dTelog;

	FILE *ioRES , *ioOUT ;
	char chLine[100];

	/* this will be limit to the number of command chLines we can still put in */
	long int nleft;

	/* file to output short form of calculation's results */
	if( (ioRES = fopen("hazy_coolingcurve.txt","w")) == NULL )
	{
		printf(" could not open hazy_coolingcurve.txt for writing.\n");
		exit(1);
	}

	/* file to output short form of calculation's results */
	if( (ioOUT = fopen("hazy_coolingcurve.out","w")) == NULL )
	{
		printf(" could not open hazy_coolingcurve.out for writing.\n");
		exit(1);
	}

	/* the log of the hydrogen density cm-3 */
	hden = 0.;

	/* the log of the initial and final temperatures 
	 * this calc has no ionization at very
	 * low temperatures, except for cosmic ray collisions and the cosmic background */
	telog = 1.;
	tehigh = 9.;

	/* increment in log of T, normally 0.1 */
	dTelog = 0.1;

	/* print simple header */
	fprintf(ioRES, "log T\tlog cool/n2\n" ); 
	fprintf(stderr,"log T\tlog cool/n2\n" ); 

	/* loop over all densities */
	while( telog <= (tehigh+0.0001) )
	{
		/* initialize the code for this run */
		cdInit();

		/* we do not want to generate any output */
		cdOutp( ioOUT );
		cdTalk( true );

		/* if this is uncommented the calculation will not be done,
		 * but all parameters will be generated, as a quick way to see
		 * that grid is set up properly */
		/*cdNoExec( );*/

		/* cosmic background, microwave and hard parts */
		nleft = cdRead( "background 0 "  );

		/* cosmic ray background, this is included because drives
		 * the chemistry in molecular gas */
		nleft = cdRead( "cosmic ray background "  );

		/* this is a pure collisional model to turn off photoionization 
		nleft = cdRead( "no photoionization "  );*/

		/* set a continuum shape, even though not used 
		nleft = cdRead( "table agn "  );
		nleft = cdRead( "phi(h) -4 "  );*/

		/* do only one zone */
		nleft = cdRead( "stop zone 1 "  );

		/* set the hydrogen density */
		sprintf(chLine,"hden %f ",hden);
		nleft = cdRead( chLine  );

		/* sets the gas kinetic temperature */
		sprintf(chLine,"constant temper %f ",telog);
		nleft = cdRead( chLine  );

		/* actually call the code */
		lgBAD = cdDrive();

		/* get cooling for last zone */
		cooling = cdCooling_last();

		/* want to print cooling over density squared */
		cooling = cooling / pow(10.,hden*hden);

		fprintf(ioRES, "%.2f\t%.3f", telog , log10( cooling ) ); 
		fprintf(stderr,"%.2f\t%.3f", telog , log10( cooling ) ); 

		if( lgBAD )
		{
			fprintf(ioRES ,"\t problems!!\n");
			fprintf(stderr,"\t problems!!\n");
		}
		else
		{
			fprintf(ioRES ,"\n");
			fprintf(stderr,"\n");
		}

		telog += dTelog;
	}

	puts( "[hazy_coolingcurve ends]" );
	exit(0);
}

